Class: App42::Base::Help

Inherits:
Object
  • Object
show all
Defined in:
lib/app42/base/help.rb

Class Method Summary collapse

Class Method Details

.activitiesObject



777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
# File 'lib/app42/base/help.rb', line 777

def activities
  print "Usage:\n  app42 activities\n\n  List all activities with their status \n\nExample:\n  $app42 activities\n  +------------+-----------+------+------+-----------------------+\n  |                   === User Activities ===                    |\n  +------------+-----------+------+------+-----------------------+\n  | Operation  | Status    | Name | Type | Date                  |\n  +------------+-----------+------+------+-----------------------+\n  | setupInfra | COMPLETED | demo | APP  | 2013-10-25 06:18:42.0 |\n  | scale      | COMPLETED | demo | APP  | 2013-10-25 06:40:39.0 |\n  | scale      | COMPLETED | demo | APP  | 2013-10-25 06:41:25.0 |\n  | descale    | COMPLETED | demo | APP  | 2013-10-25 06:42:12.0 |\n  | descale    | COMPLETED | demo | APP  | 2013-10-25 06:42:13.0 |\n  | restart    | COMPLETED | demo | APP  | 2013-10-25 06:44:31.0 |\n  | stop       | COMPLETED | demo | APP  | 2013-10-25 06:45:23.0 |\n  | start      | COMPLETED | demo | APP  | 2013-10-25 06:45:49.0 |\n  | scale      | COMPLETED | demo | APP  | 2013-10-25 06:52:56.0 |\n  | scale      | COMPLETED | demo | APP  | 2013-10-25 06:53:24.0 |\n  | descale    | COMPLETED | demo | APP  | 2013-10-25 06:58:10.0 |\n  | descale    | COMPLETED | demo | APP  | 2013-10-25 06:58:10.0 |\n  +------------+-----------+------+------+-----------------------+\n  DESC\nend\n"

.addcustomurlObject



1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
# File 'lib/app42/base/help.rb', line 1317

def addcustomurl
  print "Usage:\n  app42 addCustomURL\n\n  Add a custom URL to an app\n\nExample:\n  $app42 addCustomURL\n  Enter App Name: demo\n\n  Enter Custom URL: http://test.naveengoswami.com\n\n  Adding Custom URL To Application demo... OK\n  Custom URL added successfully.\n DESC\nend\n"

.addkeysObject



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/app42/base/help.rb', line 149

def addkeys
  print "Usage:\n  app42 addKeys\n\n  Add API key and Secret key\n\nOptions:\n  [--apiKey=API_KEY]            # API Key to add.\n  [--secretKey=SECRET_KEY]      # Secret Key to add.\n\nExample:\n  $app42 addKeys\n  == Enter your App42PaaS keys ==\n  Enter API Key:: <apiKey>\n  Enter Secret Key:: <secretKey>\n  Adding keys...done\n  DESC\nend\n"

.app42_updateObject



850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
# File 'lib/app42/base/help.rb', line 850

def app42_update
  print "Usage:\n  app42 app42-update\n\n  Update App42PaaS client(app42)\n  -> Download app42 client, In a terminal, go to the folder where you have downloaded the client and run client update command.\n\nExample:\n  $app42 app42-update\n  Uninstalling current app42 client\n  Remove executables:\n    app42\n\n  in addition to the gem? [Yn]  y\n  Removing app42\n  Successfully uninstalled app42-0.5.0\n  Installing latest app42 client\n  Successfully installed app42-0.5.0\n  1 gem installed\n  Installing ri documentation for app42-0.5.0...\n  Installing RDoc documentation for app42-0.5.0...\n    DESC\nend\n"

.appinfoObject



475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
# File 'lib/app42/base/help.rb', line 475

def appinfo
  print "Usage:\n  app42 appInfo\n\n  Show the meta information of the application\n\nOptions:\n  [--app APP]      # Name of app, you want to info\n\nExample:\n  $app42 appInfo\n  Enter App Name: demo\n  +--------------------------------+------------+-----------------+------+------------+----------------+---------------+--------+\n  |                                                      === demo Info ===                                                      |\n  +--------------------------------+------------+-----------------+------+------------+----------------+---------------+--------+\n  | App Url                        | App Status | Iaas Provider   | Name | Runtime    | Instance Count | Framework     | Memory |\n  +--------------------------------+------------+-----------------+------+------------+----------------+---------------+--------+\n  | https://demo.iab.app42paas.com | RUNNING    | Amazon (Oregon) | demo | Ruby 2.0.0 | 1              | Ruby on Rack  | 256 MB |\n  +--------------------------------+------------+-----------------+------+------------+----------------+---------------+--------+\n DESC\nend\n"

.appsObject



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/app42/base/help.rb', line 231

def apps
  print "Usage:\n  app42 apps\n\n  List all the deployed applications with their meta details\n\nExample:\n  $app42 apps\n  \n  +--------------------------------+------------+-----------------+------+------------+----------------+---------------+--------+\n  |                                                       === My Apps ===                                                       |\n  +--------------------------------+------------+-----------------+------+------------+----------------+---------------+--------+\n  | App Url                        | App Status | Iaas Provider   | Name | Runtime    | Instance Count | Framework     | Memory |\n  +--------------------------------+------------+-----------------+------+------------+----------------+---------------+--------+\n  | https://demo.iab.app42paas.com | RUNNING    | Amazon (Oregon) | demo | Ruby 2.0.0 | 1              | Ruby on Rack  | 256 MB |\n  +--------------------------------+------------+-----------------+------+------------+----------------+---------------+--------+\n"

end

.appstateObject



498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
# File 'lib/app42/base/help.rb', line 498

def appstate
  print "Usage:\n  app42 appState\n\n  Show current state of the application\n\nOptions:\n  [--app APP]      # Name of app\n\nExample:\n  $app42 appState --app demo\n  +--------------------+\n  | === demo State === |\n  +--------------------+\n  | RUNNING            |\n  +--------------------+\n  DESC\nend\n"

.bindinfoObject



946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
# File 'lib/app42/base/help.rb', line 946

def bindinfo
  print "Usage:\n  app42 bindInfo\n\n  Show IP bind information related to provisioned service\n\nExample:\n  $app42 bindInfo\n  1: mysqldemo\n  Select Service [mysqldemo]: \n\n  +---------------+---------------+----------------+-----------------+---------+------------------+---------+--------------+----------------------------------+--------+--------------+\n  |                                                                             === mysqldemo Details ===                                                                             |\n  +---------------+---------------+----------------+-----------------+---------+------------------+---------+--------------+----------------------------------+--------+--------------+\n  | Database Name | Iaas Provider | Vm Ip          | Source Ip       | State   | User Name        | Vm Port | Service Type | Password                         | Memory | Service Name |\n  +---------------+---------------+----------------+-----------------+---------+------------------+---------+--------------+----------------------------------+--------+--------------+\n  | demodb        | Amazon        | 54.218.127.245 | 122.162.124.222 | RUNNING | j7zz1jsx1bb4eiz1 | 49695   | MySQL 5.5.1  | z2qo1vxeadak6jsmt9upobytwptc5eo0 | 512 MB | mysqldemo    |\n  +---------------+---------------+----------------+-----------------+---------+------------------+---------+--------------+----------------------------------+--------+--------------+\n    DESC\nend\n"

.bindipObject



897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
# File 'lib/app42/base/help.rb', line 897

def bindip
  print "Usage:\n  app42 bindIP\n\n  Bind IP to provisioned service\n\nExample:\n  $app42 bindIP\n  Enter Service Name: mysqldemo\n\n  Please Provide Source IP\n  (For public access, use '0.0.0.0'): <IP address>\n\n  Binding IP to service... OK\n  \n  Operation is in progress, Please wait...-\n  Service bind with IP successfully.\n\n  +---------------+---------------+----------------+-----------------+---------+------------------+---------+--------------+----------------------------------+--------+--------------+\n  |                                                                             === mysqldemo Details ===                                                                             |\n  +---------------+---------------+----------------+-----------------+---------+------------------+---------+--------------+----------------------------------+--------+--------------+\n  | Database Name | Iaas Provider | Vm Ip          | Source Ip       | State   | User Name        | Vm Port | Service Type | Password                         | Memory | Service Name |\n  +---------------+---------------+----------------+-----------------+---------+------------------+---------+--------------+----------------------------------+--------+--------------+\n  | demodb        | Amazon        | 54.218.127.245 | 122.162.124.222 | RUNNING | j7zz1jsx1bb4eiz1 | 49695   | MySQL 5.5.1  | z2qo1vxeadak6jsmt9upobytwptc5eo0 | 512 MB | mysqldemo    |\n  +---------------+---------------+----------------+-----------------+---------+------------------+---------+--------------+----------------------------------+--------+--------------+\n    DESC\nend\n"

.bpaasinfoObject



1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
# File 'lib/app42/base/help.rb', line 1017

def bpaasinfo
  print "Usage:\n  app42 bPaaSInfo\n\n  Show setup information\n\nExample:\n  $app42 bPaaSInfo\n  Enter Setup Name: demo\n\n  +-----------------------+----------------------------------------+------------+-----------------+------------+---------+---------------+--------------+-------------------------------------+\n  |                                                                                   === demo Details ===                                                                                    |\n  +-----------------------+----------------------------------------+------------+-----------------+------------+---------+---------------+--------------+-------------------------------------+\n  | Created On            | Api Server Url                         | Setup Name | Iaas Provider   | Setup Type | Vm Type | Setup Flavour | Setup Status | App Hq Url                          |\n  +-----------------------+----------------------------------------+------------+-----------------+------------+---------+---------------+--------------+-------------------------------------+\n  | 2014-02-24 08:00:21.0 | https://democloudapi.iab.app42paas.com | demo       | Amazon (Oregon) | BPaaS      | Shared  | light         | RUNNING      | https://demoapphq.iab.app42paas.com |\n  +-----------------------+----------------------------------------+------------+-----------------+------------+---------+---------------+--------------+-------------------------------------+\n    DESC\nend\n"

.bpaassetupsObject



1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
# File 'lib/app42/base/help.rb', line 1038

def bpaassetups
  print "Usage:\n  app42 bPaaSSetups\n\n  List all the BPaaS setups\n\nExample:\n  $app42 bPaaSSetups\n\n  +-----------------------+----------------------------------------+------------+-----------------+------------+--------------------------+---------+---------------+--------------+-------------------------------------+\n  |                                                                                                 === Setups List ===                                                                                                  |\n  +-----------------------+----------------------------------------+------------+-----------------+------------+--------------------------+---------+---------------+--------------+-------------------------------------+\n  | Created On            | Api Server Url                         | Setup Name | Iaas Provider   | Setup Type | Email                    | Vm Type | Setup Flavour | Setup Status | App Hq Url                          |\n  +-----------------------+----------------------------------------+------------+-----------------+------------+--------------------------+---------+---------------+--------------+-------------------------------------+\n  | 2014-02-24 08:00:21.0 | https://democloudapi.iab.app42paas.com | demo       | Amazon (Oregon) | BPaaS      | [email protected] | Shared  | light         | RUNNING      | https://demoapphq.iab.app42paas.com |\n  +-----------------------+----------------------------------------+------------+-----------------+------------+--------------------------+---------+---------------+--------------+-------------------------------------+\n    DESC\nend\n"

.clearkeysObject



169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/app42/base/help.rb', line 169

def clearkeys
  print "Usage:\n  app42 clearKeys\n\n  Clear API key and Secret key\n\nExample:\n  app42 clearKeys\n  Do you want to delete existing keys? [Yn]: y\n\n  === API key and Secret key have been deleted. ===\n  DESC\nend\n"

.commandsObject

list available commands or display help for a specific command



15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/app42/base/help.rb', line 15

def self.commands

 print  "\n  \#{how_to}\n\n  Thank You for installing App42 PaaS Ruby Client! This is a powerful tool to make your Applications live with-in minutes.\n  App42 PaaS is world's most advanced PaaS solution which supports multiple languages(Java, PHP, Ruby, Nodejs) and services\n  (RDBMS like MySQL and PostgreSQL to NoSQL storage like MongoDB, Redis and CouchDB). To Get Started Signup at app42paas.shephertz.com,\n  get your API Key and Secret key after you login and finally use App42 command to push your code to cloud. Enjoy Coding!! \n\n  Key\n   keys                    #  List API key and Secret key\n   addKeys                 #  Add API key and Secret key\n   clearKeys               #  Clear API key and Secret key\n\n  Applications \n   setupInfra              #  Setup your deployment and runtime environment i.e. Instance(Memory, CPU) and Technology Stack\n   deploy                  #  Deploy the application over your runtime environment\n   update                  #  Update the application over your runtime environment\n   scale                   #  Scale application either by number of instance(s) OR kontena(s)\n   descale                 #  Descale application either by number of instance(s) OR kontena(s)\n   start                   #  Start the application\n   stop                    #  Stop the application\n   restart                 #  Restart the application\n   deleteInfra             #  Delete the Infrastructure environment\n   apps                    #  List all the deployed applications with their meta details\n   appInfo                 #  Show meta information of the application\n   appState                #  Show current state of the application\n   logs                    #  Returns the log file URL(s) for the application\n   addCustomURL            #  Add a custom URL to an app\n   removeCustomURL         #  Remove a custom URL from an app\n   customURLInfo           #  List all custom URL(s) of an app\n\n  Services \n   createService           #  Creates a new service e.g. MySQL, MongoDB, CouchDB, PostgreSQL, Redis etc.\n   deleteService           #  Delete provisioned service\n   startService            #  Start the service\n   restartService          #  Restart the service\n   stopService             #  Stop the service\n   resetServicePassword    #  Reset password of provisioned service\n   scaleService            #  Vertically scale service by number of Kontena(s)\n   descaleService          #  Vertically descale services by number of Kontena(s)\n   uploadBackup            #  Upload existing backup into a service\n   bindIP                  #  Bind IP to provisioned service\n   unbindIP                #  Unbind IP from provisioned service\n   bindInfo                #  Show IP bind information related to provisioned service\n   services                #  List all the provisioned services with their meta details\n   serviceInfo             #  Show meta information of the provisioned service\n\n  BPaaS\n   setupBPaaS             #  Setup App42 BPaaS by choosing required configuration\n   deleteBPaaS            #  Delete the BPaaS setup\n   startBPaaS             #  Start the BPaaS setup\n   stopBPaaS              #  Stop the BPaaS setup\n   upgradeBPaas           #  Upgrade BPaaS by choosing required configuration\n   downgradeBPaas         #  Downgrade BPaaS by choosing required configuration\n   bPaaSInfo              #  Show BPaaS setup information\n   bPaaSSetups            #  List all the BPaaS setups\n\n  WordPress\n   setupWordPress         #  Setup App42 WordPress by choosing required configuration\n   deleteWordPress        #  Delete the WordPress setup\n   startWordPress         #  Start the WordPress setup\n   stopWordPress          #  Stop the WordPress setup\n   upgradeWordPress       #  Upgrade WordPress by choosing required configuration\n   downgradeWordPress     #  Downgrade WordPress by choosing required configuration\n   wordPressInfo          #  Show WordPress setup information\n   wordPressSetups        #  List all the WordPress setups\n\n  GPaaS\n   setupGPaaS             #  Setup App42 GPaaS by choosing required configuration\n   deleteGPaaS            #  Delete the GPaaS setup\n   startGPaaS             #  Start the GPaaS setup\n   stopGPaaS              #  Stop the GPaaS setup\n   upgradeGPaas           #  Upgrade GPaaS by choosing required configuration\n   downgradeGPaas         #  Downgrade GPaaS by choosing required configuration\n   gPaaSInfo              #  Show GPaaS setup information\n   gPaaSSetups            #  List all the GPaaS setups\n\n  Help\n   version                 #  Show Ruby client gem version\n   help                    #  List available commands and their description\n   COMMAND --help          #  Display detailed help of a specific command\n\n  Misc\n   supportedServices       #  List supported services by App42\n   iaasProviders           #  List supported IaaS providers by App42\n   runtimes                #  List supported runtimes by App42\n   activities              #  List all activities with their status\n  USAGE\nend\n"

.createserviceObject



541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
# File 'lib/app42/base/help.rb', line 541

def createservice
  print "Usage:\n  app42 createService\n\n  Creates a new service e.g. MySQL, MongoDB, CouchDB, PostgreSQL etc.\n\nExample:\n  $app42 createService\n  Enter Service Name: mysqldb\n  Checking Service Name Availability... OK\n\n  1: MySQL 5.5.31\n  2: Mongodb 2.4.4\n  3: Couchdb 1.0.1\n  4: PostgreSQL 9.1.9\n  Select Service [MySQL 5.5.31]: \n\n  Enter Database Name: demo_db\n\n  1: Shared\n  Select Instance Type [Shared]: \n\n  1: Amazon (Oregon)\n  Select IaaS Provider [Amazon (Oregon)]: \n\n  Specify Kontena Power: 1\n\n  Creating Service... OK\n\n  Operation is in progress, Please wait...|\n  Service created successfully.\n\n  +---------------+-----------------+----------------------------------+--------------+---------+------------------+---------+--------------+----------------------------------+--------+--------------+\n  |                                                                                      === mysqldb Details ===                                                                                       |\n  +---------------+-----------------+----------------------------------+--------------+---------+------------------+---------+--------------+----------------------------------+--------+--------------+\n  | Database Name | Iaas Provider   | Token                            | Vm Ip        | State   | User Name        | Vm Port | Service Type | Password                         | Memory | Service Name |\n  +---------------+-----------------+----------------------------------+--------------+---------+------------------+---------+--------------+----------------------------------+--------+--------------+\n  | demo_db       | Amazon (Oregon) | ytxsq0ov7lf5s4foh2igw01bwy32ydgp | 172.16.2.167 | RUNNING | aoafi8vgczxoftw4 | 12411   | MySQL 5.5.31 | a2rzmvrdr7hpa08a6k1a1r24ixdutyl9 | 256 MB | mysqldb      |\n  +---------------+-----------------+----------------------------------+--------------+---------+------------------+---------+--------------+----------------------------------+--------+--------------+\n  DESC\nend\n"

.customurlinfoObject



1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
# File 'lib/app42/base/help.rb', line 1353

def customurlinfo
    print "Usage:\n  app42 customURLInfo\n\n  List all custom URLs of an app\n\nExample:\n  $app42 customURLInfo\n  Enter App Name: demo\n\n  +----------+-----------------------+-------------------------------+\n  |                === testPhp Custome URLs Details ===              |\n  +----------+-----------------------+-------------------------------+\n  | App Name | Created On            | Url                           |\n  +-------------+-----------------------+----------------------------+\n  | demo     | 2014-01-27 06:35:55.0 | http://test.naveengoswami.com |\n  +----------+-----------------------+-------------------------------+\n  DESC\nend\n"

.deletebpaasObject



1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
# File 'lib/app42/base/help.rb', line 1000

def deletebpaas
  print "Usage:\n  app42 deleteBPaaS\n\n  Delete the setup\n\nExample:\n  $app42 deleteBPaaS\n  Enter Setup Name: demo\n  Deleting Setup... OK\n\n  Operation is in progress, Please wait...-\n  Setup deleted successfully.\n    DESC\nend\n"

.deletegpaasObject



1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
# File 'lib/app42/base/help.rb', line 1484

def deletegpaas
  print "Usage:\n  app42 deleteGPaaS\n\n  Delete the GPaaS setup\n\nExample:\n  $app42 deleteGPaaS\n  Enter Setup Name: demo\n  Deleting Setup... OK\n\n  Operation is in progress, Please wait...-\n  Setup deleted successfully.\n    DESC\nend\n"

.deleteinfraObject



373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/app42/base/help.rb', line 373

def deleteinfra
  print "Usage:\n  app42 deleteInfra\n\n  Delete the Infrastructure environment\n\nOptions:\n  [--app APP]      # Name of app, you want to delete\n\nExample:\n  $app42 deleteInfra --app demo\n  Deleting Application demo... OK\n\n  Operation is in progress, Please wait...\n  1 out of 3 deleted\n  -\n  2 out of 3 deleted\n  |\n  App deleted successfully.\n  DESC\nend\n"

.deleteserviceObject



584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/app42/base/help.rb', line 584

def deleteservice
  print "Usage:\n  app42 deleteService\n\n  Delete the provisioned service\n\nOptions:\n  [--service SERVICE]      # Name of service  \n\nExample:\n  $app42 deleteService\n  Enter Service Name: mysqldemo\n\n  Deleting Service... OK\n  \n  Operation is in progress, Please wait...|\n  Service deleted successfully.  \n  DESC\nend\n"

.deletewordpressObject



1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
# File 'lib/app42/base/help.rb', line 1255

def deletewordpress
  print "Usage:\n  app42 deleteWordPress\n\n  Delete the WordPress setup\n\nExample:\n  $app42 deleteWordPress\n  Enter Setup Name: demo\n  Deleting Setup... OK\n\n  Operation is in progress, Please wait...-\n  Setup deleted successfully.\n    DESC\nend\n"

.deployObject



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/app42/base/help.rb', line 252

def deploy
  print "Usage:\n  app42 deploy\n\n  Deploy the application over your runtime environment\n\nOptions:\n  [--app APP]      # Name of app, you want to update\n\nExample:\n  $app42 deploy\n  Enter App Name: demo\n  1: Binary\n  2: Source\n  Choose Upload Type [Binary]: 2\n\n  Enter Git URL?: https://github.com/shepHertz/demo.git\n  Deploying Application... OK\n\n  Operation is in progress, Please wait...|\n  App deployed successfully.\n  DESC\n\nend\n"

.descaleObject



396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/app42/base/help.rb', line 396

def descale
  print "Usage:\n  app42 descale\n\n  Descale application either by number of instance(s) OR kontena(s)\n\nOptions:\n  [--app APP]      # Name of app, you want to descale\n\nExample:\n  $app42 descale\n  Enter App Name: demo\n\n  1: Horizontal\n  2: Vertical\n  Choose Scale Type [Horizontal]: \n\n  Horizontal descale by instance(s) [1]: 1\n  Descaling Application demo by instance 1... OK\n\n  Operation is in progress, Please wait...|\n  Descale completed successfully.\n  DESC\nend\n"

.descaleserviceObject



669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
# File 'lib/app42/base/help.rb', line 669

def descaleservice
  print "  Usage:\n    app42 descaleService\n    Vertically descale service by number of kontena(s)\n\n  Options:\n    [--service SERVICE]      # Name of service, you want to scale\n\n  Example:\n    $app42 descaleService\n    Enter Service Name: mysqldb\n    \n    Vertical descale by kontena power(s) [1]: 1\n    Descaling Service 'mysqldb' by kontena 1... OK\n\n    Operation is in progress, Please wait...|\n    Service descale completed successfully.\n  DESC\n\nend\n"

.downgradebpaasObject



1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
# File 'lib/app42/base/help.rb', line 1117

def downgradebpaas
  print "Usage:\n  app42 downgradeBPaaS\n\n  Downgrade BPaaS by choosing required configuration\n\nExample:\n  $app42 downgradeBPaaS\n  Enter Setup Name: demo\n\n  1: Light\n  2: Medium\n  Select Flavour [Light]: 2\n\n  Downgrading Setup... OK\n\n  Operation is in progress, Please wait...-\n  \n  BPaaS setup demo downgraded successfully. \n    DESC\nend\n"

.downgradegpaasObject



1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/app42/base/help.rb', line 1463

def downgradegpaas
  print "Usage:\n  app42 downgradeGPaaS\n\n  Downgrade GPaaS by choosing required configuration\n\nExample:\n  $app42 downgradeGPaaS\n  Enter Setup Name: demo\n\n  1: t1.micro\n  Select Instance Configuration [t1.micro]:\n\n  Downgrading Setup... OK\n\n  Operation is in progress, Please wait...-\n  GPaaS Setup has been updated successfully.\n    DESC\nend\n"

.downgradewordpressObject



1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
# File 'lib/app42/base/help.rb', line 1232

def downgradewordpress
  print "Usage:\n  app42 downgradeWordpress\n\n  Downgrade WordPress by choosing required configuration\n\nExample:\n  $app42 upgradeWordPress\n  Enter Setup Name: demo\n\n  1: Light\n  2: Medium\n  Select Flavour [Light]: 2\n\n  Downgrading Setup... OK\n\n  Operation is in progress, Please wait...-\n  \n  WordPress setup demo downgraded successfully. \n    DESC\nend\n"

.gpaasinfoObject



1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/app42/base/help.rb', line 1501

def gpaasinfo
  print "Usage:\n  app42 gPaaSInfo\n\n  Show GPaaS setup information\n\nOptions:\n  [--setup SETUP]      # Name of setup, you want to info\n\nExample:\n  $ app42 gPaaSInfo\n  Enter Setup Name: demo\n\n  +-----------------------+-------------------------------------------+------------+----------------------------+------------+-----------+---------------+--------------+\n  |                                                                        === gpaas Details ===                                                                        |\n  +-----------------------+-------------------------------------------+------------+----------------------------+------------+-----------+---------------+--------------+\n  | Created On            | Api Server Url                            | Setup Name | Iaas Provider              | Setup Type | Vm Type   | Setup Flavour | Setup Status |\n  +-----------------------+-------------------------------------------+------------+----------------------------+------------+-----------+---------------+--------------+\n  | 2014-02-21 09:36:43.0 | ec2-54-237-87-107.compute-1.amazonaws.com |  demo      | Amazon (Northern Virginia) | GPaaS      | Dedicated | t1.micro      | RUNNING      |\n  +-----------------------+-------------------------------------------+------------+----------------------------+------------+-----------+---------------+--------------+\n DESC\nend\n"            

.gpaassetupsObject



1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
# File 'lib/app42/base/help.rb', line 1525

def gpaassetups
    print "Usage:\n  app42 gPaaSSetups\n\n  List all the GPaaS setups\n\nExample:\n  $app42 app42 gPaaSSetups\n\n  +-----------------------+-------------------------------------------+------------+----------------------------+------------+--------------------------+-----------+---------------+--------------+\n  |                                                                                      === Setups List ===                                                                                       |\n  +-----------------------+-------------------------------------------+------------+----------------------------+------------+--------------------------+-----------+---------------+--------------+\n  | Created On            | App Url                                   | Setup Name | Iaas Provider              | Setup Type | Email                    | Vm Type   | Setup Flavour | Setup Status |\n  +-----------------------+-------------------------------------------+------------+----------------------------+------------+--------------------------+-----------+---------------+--------------+\n  | 2014-02-06 13:49:07.0 | ec2-54-221-96-246.compute-1.amazonaws.com | demo       | Amazon (Northern Virginia) | GPaaS      | [email protected] | Dedicated | t1.micro      | RUNNING      |\n  +-----------------------+-------------------------------------------+------------+----------------------------+------------+--------------------------+-----------+---------------+--------------+\n\n  DESC\nend\n"

.how_toObject

details, how to use app42 commands



10
11
12
# File 'lib/app42/base/help.rb', line 10

def self.how_to
  Paint["Usage: app42 COMMAND [command-specific-options]", :blue]
end

.iaasprovidersObject



830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
# File 'lib/app42/base/help.rb', line 830

def iaasproviders
  print "Usage:\n  app42 iaasProviders\n\n  List the supported IaaS providers by App42\n\nExample:\n  $app42 iaasProviders\n  +-----------------+-----------------+\n  | === Available IaaS Providers ===  |\n  +-----------------+-----------------+\n  | Name            | Zone            |\n  +-----------------+-----------------+\n  | Amazon          | (Oregon)        |\n  +-----------------+-----------------+\n  DESC\nend\n"

.keysObject



135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/app42/base/help.rb', line 135

def keys
  print "Usage:\n  app42 keys\n\n  List API key and Secret key\n\nExample:\n  === API/Secret Key ===\n  API Key      = <apiKey>\n  Secret Key   = <secretKey>\n  DESC\nend\n"

.keys_helpObject



108
109
110
111
112
113
114
115
116
117
# File 'lib/app42/base/help.rb', line 108

def self.keys_help
  print "  \#{how_to}\n  app42 api_key:add [KEY]       #  add a api key for the current user\n  app42 secret_key:add [KEY]    #  add a Secret Key for the current user\n  app42 keys:clear              #  remove all authentication keys from the current user\n\n  USAGE\n\nend\n"

.logsObject



518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
# File 'lib/app42/base/help.rb', line 518

def logs
  print "Usage:\n  app42 logs\n\n  Returns the log URL(s) for the application\n\nExample:\n  $app42 logs\n  Enter App Name: demo\nPlease visit below URL(s) to access app logs\n\n+-----------------------------------------------------------------------------------+\n|                                    Log URL(s)                                     |\n+-----------------------------------------------------------------------------------+\n| https://apphq.app42paas.com/app/getInstanceLog?id=eyk3t10hz9nwc12e08f92jxcmz83uo2u |\n| https://apphq.app42paas.com/app/getInstanceLog?id=zijqty8n5ufna677wgbxwywca5laqkw5 |\n| https://apphq.app42paas.com/app/getInstanceLog?id=wynv58rt509yj7fqwbkh80zlw6isf6g2 |\n+-----------------------------------------------------------------------------------+\n  DESC\nend\n"

.removecustomurlObject



1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
# File 'lib/app42/base/help.rb', line 1335

def removecustomurl
  print "Usage:\n  app42 removeCustomURL\n\n  Remove a custom URL from an app\n\nExample:\n  $ app42 removeCustomURL\n  Enter App Name: demo\n\n  Enter Custom URL: http://test.naveengoswami.com\n\n  Removing Custom URL... OK\n  Custom URL deleted successfully.\n DESC\nend\n"

.resetservicepasswordObject



875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
# File 'lib/app42/base/help.rb', line 875

def resetservicepassword
  print "Usage:\n  resetServicePassword\n\n  Reset the password of provisioned service\n\nExample:\n  $resetServicePassword\n  Enter Service Name: mysqldemo\n\n  Enter Old Password: teh77o4b6kpb22ab6oogfu9lwru9vrlj\n\n  Resetting Password... OK\n  \n  Operation is in progress, Please wait.../\n  Service Password has been reset successfully.\n\n  Your new password is: z2qo1vxeadak6jsmt9upobytwptc5eo0\n    DESC\nend\n"

.restartObject



350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/app42/base/help.rb', line 350

def restart
  print "Usage:\n  app42 restart\n\n  Restart the application\n\nOptions:\n  [--app APP]      # Name of app, you want to restart\n\nExample:\n  $app42 start --app demo\n  Restarting Application demo... OK\n\n  Operation is in progress, Please wait...\n  1 out of 3 restarted\n  -\n  2 out of 3 restarted\n  |\n  App restarted successfully.\n  DESC\nend\n"

.restartserviceObject



691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
# File 'lib/app42/base/help.rb', line 691

def restartservice
  print "Usage:\n  app42 restartService\n\n  Restart the service\n\nOptions:\n  [--app Service]      # Name of service, you want to start\n\nExample:\n  $app42 restartService\n  Enter Service Name: mysql\n  Restarting Service mysql... OK\n\n  Operation is in progress, Please wait...|\n  Service restarted successfully.\n  DESC\n\nend\n"

.runtimesObject



807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
# File 'lib/app42/base/help.rb', line 807

def runtimes
  print "Usage:\n  app42 runtimes\n\n  List the supported runtimes\n\nExample:\n  $app42 runtimes\n  +--------------+--------------+\n  | === Available Runtimes ===  |\n  +--------------+--------------+\n  | Name         | Version      |\n  +--------------+--------------+\n  | Ruby         | 2.0          |\n  | Java         | 6.0          |\n  | Java         | 7.0          |\n  | Php          | 5.3          |\n  | Php          | 5.5          |\n  +--------------+--------------+\n  DESC\nend\n"

.scaleObject



422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
# File 'lib/app42/base/help.rb', line 422

def scale
  print "Usage:\n  app42 scale\n\n  Scale application either by number of instance(s) OR kontena(s)\n\nOptions:\n  [--app APP]      # Name of app, you want to scale\n\nExample:\n  $app42 scale\n  Enter App Name: demo\n\n  1: Horizontal\n  2: Vertical\n  Choose Scale Type [Horizontal]: 2\n\n  Vertical scale by kontena power(s) [1]: \n  Scaling Application demo by kontena(s) 1... OK\n\n  Operation is in progress, Please wait...|\n\n  Scale completed successfully.\n  DESC\nend\n"

.scaleserviceObject



647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
# File 'lib/app42/base/help.rb', line 647

def scaleservice
  print "  Usage:\n    app42 scaleService\n    Vertically scale service by number of kontena(s)\n  \n  Options:\n    [--service SERVICE]      # Name of service, you want to scale\n  \n  Example:\n  $app42 scaleService\n  Enter Service Name: mysqldb\n  \n  Vertical scale by kontena power(s) [1]: 1\n  Scaling Service 'mysqldb' by kontena 1... OK\n\n  Operation is in progress, Please wait...|\n  Service scale completed successfully.\n  DESC\n\nend\n"

.serviceinfoObject



731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
# File 'lib/app42/base/help.rb', line 731

def serviceinfo
  print "Usage:\n  app42 serviceInfo\n\n  Show meta information of the provisioned service\n\nOptions:\n  [--service SERVICE]      # Name of service\n\nExample:\n  1: mysqldb\n  Select Service [mysqldb]: \n\n  +---------------+-----------------+----------------------------------+--------------+---------+------------------+---------+--------------+----------------------------------+--------+--------------+\n  |                                                                                      === mysqldb Details ===                                                                                       |\n  +---------------+-----------------+----------------------------------+--------------+---------+------------------+---------+--------------+----------------------------------+--------+--------------+\n  | Database Name | Iaas Provider   | Token                            | Vm Ip        | State   | User Name        | Vm Port | Service Type | Password                         | Memory | Service Name |\n  +---------------+-----------------+----------------------------------+--------------+---------+------------------+---------+--------------+----------------------------------+--------+--------------+\n  | demo_db       | Amazon (Oregon) | ytxsq0ov7lf5s4foh2igw01bwy32ydgp | 172.16.2.167 | RUNNING | aoafi8vgczxoftw4 | 12411   | MySQL 5.5.31 | a2rzmvrdr7hpa08a6k1a1r24ixdutyl9 | 256 MB | mysqldb      |\n  +---------------+-----------------+----------------------------------+--------------+---------+------------------+---------+--------------+----------------------------------+--------+--------------+\n  DESC\nend\n"

.servicesObject



712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
# File 'lib/app42/base/help.rb', line 712

def services
  print "Usage:\n  app42 services\n\n  List the all provisioned services with their meta details\n\nExample:\n  $app42 services\n  +---------------+---------------+-----------+-----------+---------+------------------+---------+--------------+----------------------------------+--------+\n  |                                                                  === Service List ===                                                                   |\n  +---------------+---------------+-----------+-----------+---------+------------------+---------+--------------+----------------------------------+--------+\n  | Database Name | Iaas Provider | Name      | Vm Ip     | State   | User Name        | Vm Port | Service Type | Password                         | Memory |\n  +---------------+---------------+-----------+-----------+---------+------------------+---------+--------------+----------------------------------+--------+\n  | demodb        | Amazon        | mysqldemo | 10.0.0.52 | RUNNING | j7zz1jsx1bb4eiz1 | 49695   | MySQL 5.5.1  | teh77o4b6kpb22ab6oogfu9lwru9vrlj | 512 MB |\n  +---------------+---------------+-----------+-----------+---------+------------------+---------+--------------+----------------------------------+--------+\n  DESC\nend\n"

.setupbpaasObject



968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
# File 'lib/app42/base/help.rb', line 968

def setupbpaas
  print "Usage:\n  app42 setupBPaaS\n\n  Setup App42 BPaaS by choosing required configuration\n\nExample:\n  $app42 setupBPaaS\n  Enter Setup Name: demo\n  Checking Setup Name Availability... OK\n\n  1: Shared\n  Select Instance Type [Shared]: \n\n  1: Amazon (Oregon)\n  Select IaaS Provider [Amazon (Oregon)]: \n\n  1: Light\n  2: Medium\n  3: Heavy\n  Select Flavour [Light]: \n\n  Setting up the BPaaS infrastructure... OK\n\n  Operation is in progress, Please wait...-\n  BPaaS Setup has been completed successfully.\n\n  Your BPaaS setup has been completed successfully, For details, Login to PaaSHQ console.\n    DESC\nend\n"

.setupgpaasObject



1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
# File 'lib/app42/base/help.rb', line 1374

def setupgpaas
  print "Usage:\n  app42 setupGPaaS\n\n  Setup App42 GPaaS by choosing required configuration\n\nExample:\n  $ app42 setupGPaaS\n  Enter Setup Name: demo\n  Checking Setup Name Availability... OK\n\n  1: Amazon (Northern Virginia)\n  Select IaaS Provider [Amazon (Northern Virginia)]: \n\n  1: t1.micro\n  2: m1.small\n  3: m1.medium\n  4: m1.large\n  5: m1.xlarge\n  Select Instance Configuration [t1.micro]: \n\n  Setting up the GPaaS infrastructure... OK\n\n  Operation is in progress, Please wait...|\n  GPaaS Setup has been completed successfully.\n\n  Your GPaaS setup has been completed successfully, For details, Login to PaaSHQ console.\n DESC\nend\n"

.setupinfraObject



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/app42/base/help.rb', line 184

def setupinfra
  print "Usage:\n  app42 setupInfra\n\n  Setup your deployment and runtime environment i.e. Instance(Memory, CPU) and Technology Stack\n\nExample:\n  $app42 setupInfra\n  Application Name: demo\n\n  Checking App Name Availability... OK\n\n  1: Shared\n  Select Instance Type [Shared]: \n\n  1: Amazon us-west-2\n  Select IaaS Provider [Amazon us-west-2]: \n\n  1: Ruby 2.0.0\n  2: Java 6\n  3: Java 7\n  4: PHP 5.3\n  5: PHP 5.5\n  Select Runtime [Ruby 2.0.0]: \n\n  1: Ruby on Rack \n  2: Rails 4.0\n  3: Sinatra 1.4\n  Select Framework [Ruby on Rack ]: \n\n  1: Nginx 1.4.1\n  Select Web Server [Nginx 1.4.1]: \n\n  Specify Kontena Power: 5\n \n  Setting up the infrastructure... OK\n  \n  Operation is in progress, Please wait.../\n  \n  Setup Infra completed successfully.\n\n  Default application has been deployed. You can visit 'https://demo.iab.app42paas.com' to see the default application.\n  DESC\n\nend\n"

.setupwordpressObject



1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
# File 'lib/app42/base/help.rb', line 1140

def setupwordpress
  print "Usage:\n  app42 setupWordPress\n\n  Setup App42 WordPress by choosing required configuration\n\nExample:\n  $app42 setupWordPress\n  Enter Wordpress Name: demo\n\n  Checking WordPress Name Availability... OK\n\n  1: Shared\n  Select Instance Type [Shared]: \n\n  1: Amazon (Oregon)\n  Select IaaS Provider [Amazon (Oregon)]: \n\n  1: Light\n  2: Medium\n  3: Heavy\n  Select Flavour [Light]: \n\n  Setting up the wordpress infrastructure... OK\n\n  Operation is in progress, Please wait...-\n  WordPress Setup has been completed successfully.\n\n  Your WordPress setup has been completed successfully, For details, Login to PaaSHQ console.\n    DESC\nend\n"

.startObject



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/app42/base/help.rb', line 303

def start
  print "Usage:\n  app42 start\n\n  Start the application\n\nOptions:\n  [--app APP]      # Name of app, you want to start\n\nExample:\n  $app42 start --app demo\n  Starting Application demo... OK\n\n  Operation is in progress, Please wait...\n  1 out of 3 started\n  -\n  2 out of 3 started\n  |\n  App started successfully.\n  DESC\n\nend\n"

.startbpaasObject



1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
# File 'lib/app42/base/help.rb', line 1058

def startbpaas
  print "Usage:\n  app42 startBPaaS\n\n  Start the BPaaS setup\n\nExample:\n  $app42 startBPaaS\n  Enter Setup Name: demo\n  Starting BPaaS Setup demo... OK\n\n  Operation is in progress, Please wait...|\n  \n  BPaaS setup demo started successfully. \n    DESC\nend\n"

.startgpaasObject



1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
# File 'lib/app42/base/help.rb', line 1405

def startgpaas
  print "Usage:\n  app42 startGPaaS\n\n  Start the GPaaS setup\n\nExample:\n  $app42 startGPaaS\n  Enter Setup Name: demo\n  Starting GPaaS Setup fsdfds... OK\n\n  Operation is in progress, Please wait...-\n  GPaaS Setup has been started successfully.\n    DESC\nend\n"

.startserviceObject



605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
# File 'lib/app42/base/help.rb', line 605

def startservice
  print "Usage:\n  app42 startService\n\n  Start the service\n\nOptions:\n  [--app Service]      # Name of service, you want to start\n\nExample:\n  $app42 startService\n  Enter Service Name: mysql\n  Starting Service mysql... OK\n\n  Operation is in progress, Please wait...|\n  Service started successfully.\n  DESC\n\nend\n"

.startwordpressObject



1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/app42/base/help.rb', line 1173

def startwordpress
  print "Usage:\n  app42 startWordPress\n\n  Start the WordPress setup\n\nExample:\n  $app42 startWordPress\n  Enter Wordpress Name: demo\n\n  Starting Wordpress Setup demo... OK\n\n  Operation is in progress, Please wait...|\n  WordPress Setup has been started successfully. \n    DESC\nend\n"

.stopObject



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/app42/base/help.rb', line 327

def stop
  print "Usage:\n  app42 stop\n\n  Stop the application\n\nOptions:\n  [--app APP]      # Name of app, you want to stop\n\nExample:\n  $app42 stop --app demo\n  Stopping Application demo... OK\n\n  Operation is in progress, Please wait...-\n  1 out of 3 stopped\n  -\n  2 out of 3 stopped\n  -\n  App stopped successfully.\n  DESC\nend\n"

.stopbpaasObject



1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
# File 'lib/app42/base/help.rb', line 1076

def stopbpaas
  print "Usage:\n  app42 stopBPaaS\n\n  Stop the BPaaS setup\n\nExample:\n  $app42 stopBPaaS\n  Enter Setup Name: demo\n  Stopping BPaaS Setup demo... OK\n\n  Operation is in progress, Please wait...|\n  \n  BPaaS setup demo stopped successfully. \n    DESC\nend\n"

.stopgpaasObject



1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
# File 'lib/app42/base/help.rb', line 1422

def stopgpaas
  print "Usage:\n  app42 stopGPaaS\n\n  Stop the GPaaS setup\n\nExample:\n  $app42 stopGPaaS\n  Enter Setup Name: demo\n  Stopping GPaaS Setup demo... OK\n\n  Operation is in progress, Please wait...|\n  GPaaS Setup has been stopped successfully.\n  DESC\nend\n"

.stopserviceObject



626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
# File 'lib/app42/base/help.rb', line 626

def stopservice
  print "Usage:\n  app42 stopService\n\n  Stop the service\n\nOptions:\n  [--app Service]      # Name of service, you want to start\n\nExample:\n  $app42 stopService\n  Enter Service Name: mysql\n  Stopping Service mysql... OK\n\n  Operation is in progress, Please wait...|\n  Service stopped successfully.\n  DESC\n\nend\n"

.stopwordpressObject



1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
# File 'lib/app42/base/help.rb', line 1191

def stopwordpress
  print "Usage:\n  app42 stopWordPress\n\n  Stop the WordPress setup\n\nExample:\n  $app42 stopWordPress\n  Enter Wordpress Name: demo\n\n  Stopping Wordpress Setup demo... OK\n\n  Operation is in progress, Please wait...|\n  WordPress Setup has been stopped successfully.\n    DESC\nend\n"

.supportedservicesObject



755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
# File 'lib/app42/base/help.rb', line 755

def supportedservices
  print "Usage:\n  app42 supportedServices\n\n  List the supported services by App42\n\nExample:\n  $app42 supportedServices\n  +--------------+--------------+\n  | === App42 PaaS Services === |\n  +--------------+--------------+\n  | Name         | Version      |\n  +--------------+--------------+\n  | MySQL        | 5.5.1        |\n  | Mongodb      | 2.4          |\n  | Couchdb      | 10.1         |\n  | PostgreSQL   | 9.1          |\n  +--------------+--------------+\n  DESC\nend\n"

.unbindipObject



926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
# File 'lib/app42/base/help.rb', line 926

def unbindip
  print "Usage:\n  app42 unbindIP\n\n  Unbind IP from provisioned service\n\nExample:\n  $app42 unbindIP\n  Enter Service Name: mysqldemo\n\n  Please Provide Source IP: <IP address>               \n\n  Unbinding IP to service... OK\n  \n  Operation is in progress, Please wait...|\n  Service unbind with IP successfully.\n    DESC\nend\n"

.updateObject



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/app42/base/help.rb', line 278

def update
  print "Usage:\n  app42 update\n\n  Update the application over your runtime environment\n\nOptions:\n  [--app APP]      # Name of app, you want to update\n\nExample:\n  $app42 update\n  Enter App Name: demo\n  1: Binary\n  2: Source\n  Choose Upload Type [Binary]: 2\n\n  Updating Application... OK\n\n  Operation is in progress, Please wait...-\n  App deployed successfully.\n  DESC\n\nend\n"

.upgradebpaasObject



1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
# File 'lib/app42/base/help.rb', line 1094

def upgradebpaas
  print "Usage:\n  app42 upgradeBPaaS\n\n  Upgrade BPaaS by choosing required configuration\n\nExample:\n  $app42 upgradeBPaaS\n  Enter Setup Name: demo\n\n  1: Medium\n  2: Heavy\n  Select Flavour [Medium]: 2\n\n  Upgrading Setup... OK\n\n  Operation is in progress, Please wait...-\n  \n  BPaaS setup demo upgraded successfully. \n    DESC\nend\n"

.upgradegpaasObject



1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
# File 'lib/app42/base/help.rb', line 1439

def upgradegpaas
  print "Usage:\n  app42 upgradeGPaaS\n\n  Upgrade GPaaS by choosing required configuration\n\nExample:\n  $app42 upgradeGPaaS\n  Enter Setup Name: demo\n\n  1: m1.small\n  2: m1.medium\n  3: m1.large\n  4: m1.xlarge\n  Select Instance Configuration [m1.small]:\n\n  Upgrading Setup... OK\n\n  Operation is in progress, Please wait...|\n  GPaaS Setup has been updated successfully.\n    DESC\nend\n"

.upgradewordpressObject



1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
# File 'lib/app42/base/help.rb', line 1209

def upgradewordpress
  print "Usage:\n  app42 upgradeWordpress\n\n  Upgrade WordPress by choosing required configuration\n\nExample:\n  $app42 upgradeWordPress\n  Enter Setup Name: demo\n\n  1: Medium\n  2: Heavy\n  Select Flavour [Medium]: 2\n\n  Upgrading Setup... OK\n\n  Operation is in progress, Please wait...-\n  \n  WordPress setup demo upgraded successfully. \n    DESC\nend\n"

.uploadbackupObject



449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/app42/base/help.rb', line 449

def uploadbackup
  print "Usage:\n  app42 uploadBackup\n\n  Upload file data into a service\n\nOptions:\n  [--service SERVICE]      # Name of service, you want to scale\n\nExample:\n  $app42 uploadBackup\n  Enter Service Name: db\n\n  Enter Backup File Path: /home/ubuntu/Downloads/demo_production-27Nov2013.sql\n\n  Do you also want to restore uploaded backup? [Yn]: n\n  Please be patient... This process may take a while to complete.\n\n  Uploading Service Backup... OK\n\n  Operation is in progress, Please wait...\n  Backup has been successfully restored.\n  DESC\nend\n"

.usage(command) ⇒ Object

call help methods



120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/app42/base/help.rb', line 120

def Help.usage command
  if self.respond_to?(command)
    send command 
  elsif self.respond_to?(command.split(':').last)
    send command.split(':').last
  elsif self.respond_to?(command.split('-').join('_'))
    send command.split('-').join('_')  
  else
    Paint["Sorry..!!, Help is not available.\n", :red]   
  end

end

.versionObject



1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
# File 'lib/app42/base/help.rb', line 1546

def version
  print "Usage:\n  app42 version\n\n  Show Ruby client gem version \n\nExample:\n  $app42 version\n  App42 current version: 0.5.3\n    DESC\n\nend\n"

.wordpressinfoObject



1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
# File 'lib/app42/base/help.rb', line 1272

def wordpressinfo
  print "     \nUsage:\n  app42 wordPressInfo\n\n  Show WordPress setup information\n\nOptions:\n  [--setup SETUP]      # Name of setup, you want to info\n\nExample:\n  $app42 wordPressInfo\n  Enter Setup Name: demo\n  +-----------------------+----------------------------------------+------------+----------------------------+------------+---------+---------------+--------------+\n  |                                                                      === demo Details ===                                                                      |\n  +-----------------------+----------------------------------------+------------+----------------------------+------------+---------+---------------+--------------+\n  | Created On            | Api Server Url                         | Setup Name | Iaas Provider              | Setup Type | Vm Type | Setup Flavour | Setup Status |\n  +-----------------------+----------------------------------------+------------+----------------------------+------------+---------+---------------+--------------+\n  | 2014-01-02 10:10:38.0 | http://demowordpress.iaa.app42paas.com | demo       | Amazon (Northern Virginia) | WP         | Shared  | medium        | RUNNING      |\n  +-----------------------+----------------------------------------+------------+----------------------------+------------+---------+---------------+--------------+\n\n DESC\nend\n"

.wordpresssetupsObject



1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
# File 'lib/app42/base/help.rb', line 1297

def wordpresssetups
  print "Usage:\n  app42 wordPressSetups\n\n  List all the WordPress setups\n\nExample:\n  $app42 wordPressSetups\n  +-----------------------+----------------------------------------+------------+----------------------------+------------+---------+---------------+--------------+\n  |                                                                      === Setups List ===                                                                       |\n  +-----------------------+----------------------------------------+------------+----------------------------+------------+---------+---------------+--------------+\n  | Created On            | App Url                                | Setup Name | Iaas Provider              | Setup Type | Vm Type | Setup Flavour | Setup Status |\n  +-----------------------+----------------------------------------+------------+----------------------------+------------+---------+---------------+--------------+\n  | 2014-01-02 10:10:38.0 | http://demowordpress.iaa.app42paas.com | demo       | Amazon (Northern Virginia) | WP         | Shared  | medium        | RUNNING      |\n  +-----------------------+----------------------------------------+------------+----------------------------+------------+---------+---------------+--------------+\n\n DESC\nend\n"